@@ -20,11 +20,12 @@ namespace eckit::geo::range {
 
 class RegularCartesian final : public Regular {
 public:
+
     // -- Constructors
 
     using Regular::Regular;
 
-    RegularCartesian(size_t n, double a, double b, double eps = 0.) : Regular(n, a, b, false, eps) {}
+    RegularCartesian(size_t n, double a, double b);
 
     // -- Overridden methods
 
